==> kylin-ondevice-nlp-engine_1.0.0.0.orig.tar.gz: kylin-ondevice-nlp-engine-1.0.0.0/test/testondevicenlpengine.cpp <==
/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "json.hpp"
#include "ondevicenlpengine.h"
#include "utils.hpp"

#include <fstream>
#include <iostream>
#include <string>
#include <vector>

using namespace ai_engine::lm::nlp;

static std::string chatPrompt;

static void replaceAll(std::string &s, const std::string &search,
                       const std::string &replace) {
    std::string result;
    for (size_t pos = 0;; pos += search.length()) {
        auto new_pos = s.find(search, pos);
        if (new_pos == std::string::npos) {
            result += s.substr(pos, s.size() - pos);
            break;
        }
        result += s.substr(pos, new_pos - pos) + replace;
        pos = new_pos;
    }
    s = std::move(result);
}

void printResult(const std::string &result) {
    json jsonResult = json::parse(result);
    std::string content = json_value(jsonResult, "content", std::string(""));
    std::cerr << content;

    // 将 content 中的换行控制符替换成 \n
    replaceAll(content, "\n", "\\n");

    static std::string answer;
    answer += content;

    if (json_value(jsonResult, "stop", true)) {
        chatPrompt +=
            R"(, {"role": "assistant", "content": ")" + answer + R"("}, )";
        answer.clear();
        std::cerr << std::endl;
    }
}

int main(int argc, char *argv[]) {
    // 标准输出重定向到文件，使用标准错误进行对话
    freopen("/tmp/chatlog", "w", stdout);
    OndeviceNlpEngine engine;
    engine.initChatModule();
    engine.setChatResultCallback(printResult);

    std::string sp;
    std::cerr << "system prompt: ";
    std::getline(std::cin, sp);
    // 删除 sp 中的引号
    size_t pos = 0;
    while ((pos = sp.find('"', pos)) != std::string::npos) {
        sp.erase(pos, 1);
    }

    // system role prompt
    chatPrompt =
        R"({"messages": [{"role": "system", "content": ")" + sp + R"("}, )";

    while (true) {
        std::cout << std::endl;
        std::string input;
        std::cerr << "> ";
        std::getline(std::cin, input);
        if (input == "exit") {
            break;
        }
        chatPrompt += R"({"role": "user", "content": ")" + input + R"("})";
        std::cerr << "chatPrompt = " << chatPrompt << R"(],"verbose": true})"
                  << std::endl;
        // 添加 messages 缺少的 ] 关闭符号，设置 verbose
        engine.chat(chatPrompt + R"(],"verbose": true})");
        std::cerr << std::endl;
    }
    engine.destroyChatModule();
    return 0;
}

==> kylin-ondevice-nlp-engine_1.1.0.0.orig.tar.gz: kylin-ondevice-nlp-engine-1.1.0.0/test/testondevicenlpengine.cpp <==
/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "json.hpp"
#include "ondevicenlpengine.h"
#include "utils.hpp"

#include <fstream>
#include <iostream>
#include <string>
#include <vector>

using namespace ai_engine::lm::nlp;

static std::string chatPrompt;

static void replaceAll(std::string &s, const std::string &search,
                       const std::string &replace) {
    std::string result;
    for (size_t pos = 0;; pos += search.length()) {
        auto new_pos = s.find(search, pos);
        if (new_pos == std::string::npos) {
            result += s.substr(pos, s.size() - pos);
            break;
        }
        result += s.substr(pos, new_pos - pos) + replace;
        pos = new_pos;
    }
    s = std::move(result);
}

void printResult(ChatResult result) {
    json jsonResult = json::parse(result.text);
    std::string content = json_value(jsonResult, "content", std::string(""));
    std::cerr << content;

    // 将 content 中的换行控制符替换成 \n
    replaceAll(content, "\n", "\\n");

    static std::string answer;
    answer += content;

    if (json_value(jsonResult, "stop", true)) {
        chatPrompt +=
            R"(, {"role": "assistant", "content": ")" + answer + R"("}, )";
        answer.clear();
        std::cerr << std::endl;
    }
}

int main(int argc, char *argv[]) {
    // 标准输出重定向到文件，使用标准错误进行对话
    freopen("/tmp/chatlog", "w", stdout);
    OndeviceNlpEngine engine;
    ai_engine::lm::EngineError error;
    engine.initChatModule(error);
    engine.setChatResultCallback(printResult);

    std::string sp;
    std::cerr << "system prompt: ";
    std::getline(std::cin, sp);
    // 删除 sp 中的引号
    size_t pos = 0;
    while ((pos = sp.find('"', pos)) != std::string::npos) {
        sp.erase(pos, 1);
    }

    // system role prompt
    chatPrompt =
        R"({"messages": [{"role": "system", "content": ")" + sp + R"("}, )";

    while (true) {
        std::cout << std::endl;
        std::string input;
        std::cerr << "> ";
        std::getline(std::cin, input);
        if (input == "exit") {
            break;
        }
        chatPrompt += R"({"role": "user", "content": ")" + input + R"("})";
        std::cerr << "chatPrompt = " << chatPrompt << R"(],"verbose": true})"
                  << std::endl;
        // 添加 messages 缺少的 ] 关闭符号，设置 verbose
        engine.chat(chatPrompt + R"(],"verbose": true})", error);
        std::cerr << std::endl;
    }
    engine.destroyChatModule(error);
    return 0;
}
